"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useGroundingMenuItem_unstable", {
    enumerable: true,
    get: function() {
        return useGroundingMenuItem_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _keyboardkeys = require("@fluentui/keyboard-keys");
const _reactcomponents = require("@fluentui/react-components");
const _reactinputlistbox = require("@fluentui-copilot/react-input-listbox");
const _reactprovider = require("@fluentui-copilot/react-provider");
const _reacticons = require("@fluentui/react-icons");
const ChevronRightIcon = (0, _reacticons.bundleIcon)(_reacticons.ChevronRightFilled, _reacticons.ChevronRightRegular);
const ChevronLeftIcon = (0, _reacticons.bundleIcon)(_reacticons.ChevronLeftFilled, _reacticons.ChevronLeftRegular);
const useGroundingMenuItem_unstable = (props, ref)=>{
    const { className, style, ...primarySlotProps } = props;
    const { disabled, value, onOptionSelect } = primarySlotProps;
    const designVersion = (0, _reactprovider.useDesignVersion)(props.designVersion);
    const { dir } = (0, _reactcomponents.useFluent)();
    const optionRef = _react.useRef(null);
    const rootRef = (0, _reactcomponents.useMergedRefs)(optionRef, ref);
    // use the id if provided, otherwise use a generated id
    const id = (0, _reactcomponents.useId)('grounding-menu-item', props.id);
    const optionData = _react.useRef(undefined);
    const selectOption = (0, _reactinputlistbox.useInputListboxContext)((ctx)=>ctx.selectOption);
    const selectItem = _react.useCallback((event)=>{
        if (disabled) {
            event.preventDefault();
            return;
        }
        if (optionData.current) {
            selectOption(event, optionData.current);
        }
    }, [
        disabled,
        selectOption
    ]);
    const onKeyDown = _react.useCallback((event)=>{
        if (event.key === _keyboardkeys.Enter) {
            selectItem(event);
        }
    }, [
        selectItem
    ]);
    // Resolve the slot early to ensure we don't overwrite a user provided ref
    const primaryText = _reactcomponents.slot.optional(props.primaryText, {
        elementType: 'span'
    });
    const textRef = _react.useRef();
    const primaryTextRef = (0, _reactcomponents.useMergedRefs)(primaryText === null || primaryText === void 0 ? void 0 : primaryText.ref, textRef);
    if (primaryText) {
        primaryText.ref = primaryTextRef;
    }
    // register option data with context
    const registerOption = (0, _reactinputlistbox.useInputListboxContext)((ctx)=>ctx.registerOption);
    _react.useEffect(()=>{
        if (id && optionRef.current && textRef.current) {
            var _textRef_current_textContent;
            const optionText = (_textRef_current_textContent = textRef.current.textContent) !== null && _textRef_current_textContent !== void 0 ? _textRef_current_textContent : '';
            const optionValue = value !== null && value !== void 0 ? value : optionText;
            // Save a reference to the option data so other callbacks can access it
            optionData.current = {
                id,
                disabled,
                text: optionText,
                value: optionValue,
                onOptionSelect
            };
            const unregisterOption = registerOption(optionData.current, optionRef.current);
            return ()=>{
                unregisterOption();
                optionData.current = undefined;
            };
        }
    }, [
        disabled,
        id,
        onOptionSelect,
        registerOption,
        value
    ]);
    const selected = (0, _reactinputlistbox.useInputListboxContext)((ctx)=>{
        var _optionData_current;
        const selectedOptions = ctx.selectedOptions;
        return ((_optionData_current = optionData.current) === null || _optionData_current === void 0 ? void 0 : _optionData_current.value) !== undefined && selectedOptions.find((o)=>{
            var _optionData_current;
            return o === ((_optionData_current = optionData.current) === null || _optionData_current === void 0 ? void 0 : _optionData_current.value);
        }) !== undefined;
    });
    const state = {
        designVersion,
        disabled,
        selected,
        components: {
            root: 'div',
            persona: _reactcomponents.Persona,
            submenuButton: _reactcomponents.Button,
            submenuButtonTooltip: _reactcomponents.Tooltip
        },
        root: _reactcomponents.slot.always(props.root, {
            defaultProps: {
                className,
                style
            },
            elementType: 'div'
        }),
        persona: _reactcomponents.slot.always(props.persona, {
            defaultProps: {
                'aria-disabled': disabled ? true : undefined,
                role: 'menuitem',
                id,
                tabIndex: 0,
                ...primarySlotProps,
                primaryText,
                onKeyDown: (0, _reactcomponents.mergeCallbacks)(onKeyDown, props.onKeyDown),
                onClick: (0, _reactcomponents.mergeCallbacks)(selectItem, props.onClick),
                ref: rootRef
            },
            elementType: _reactcomponents.Persona
        }),
        submenuButton: _reactcomponents.slot.optional(props.submenuButton, {
            defaultProps: {
                appearance: 'transparent',
                'aria-haspopup': 'menu',
                role: 'menuitem',
                icon: dir === 'ltr' ? /*#__PURE__*/ _react.createElement(ChevronRightIcon, null) : /*#__PURE__*/ _react.createElement(ChevronLeftIcon, null)
            },
            elementType: _reactcomponents.Button
        }),
        submenuButtonTooltip: _reactcomponents.slot.optional(props.submenuButtonTooltip, {
            defaultProps: {
                relationship: 'label'
            },
            elementType: _reactcomponents.Tooltip
        })
    };
    if (state.submenuButton) {
        var _state_root_role;
        state.root.role = (_state_root_role = state.root.role) !== null && _state_root_role !== void 0 ? _state_root_role : 'group';
        state.submenuButton.onClick = (0, _reactcomponents.mergeCallbacks)(state.submenuButton.onClick, (ev)=>{
            ev.stopPropagation();
        });
        state.submenuButton.onKeyDown = (0, _reactcomponents.mergeCallbacks)(state.submenuButton.onKeyDown, (ev)=>{
            if (ev.key === _keyboardkeys.Enter) {
                ev.stopPropagation();
            }
        });
    }
    return state;
}; //# sourceMappingURL=useGroundingMenuItem.js.map
