"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useGroundingMenuSearchBox_unstable", {
    enumerable: true,
    get: function() {
        return useGroundingMenuSearchBox_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactutilities = require("@fluentui/react-utilities");
const _reacticons = require("@fluentui/react-icons");
const _GroundingCommandBar = require("../GroundingCommandBar");
const _GroundingCommandBarOverflowMenu = require("../GroundingCommandBarOverflowMenu");
const _GroundingCommandBarTab = require("../GroundingCommandBarTab");
const Search = (0, _reacticons.bundleIcon)(_reacticons.Search20Filled, _reacticons.Search20Regular);
const useGroundingMenuSearchBox_unstable = (props, ref)=>{
    const { defaultExpanded, onExpandedChange } = props;
    const [expanded, setExpanded] = (0, _reactutilities.useControllableState)({
        state: props.expanded,
        initialState: false,
        defaultState: defaultExpanded
    });
    const searchBox = useExpandingSearchBox({
        ...props,
        expanded,
        setExpanded
    });
    const expandButton = !expanded ? _reactcomponents.slot.optional(props.expandButton, {
        defaultProps: {
            icon: /*#__PURE__*/ _react.createElement(Search, null),
            appearance: 'subtle'
        },
        renderByDefault: true,
        elementType: _reactcomponents.Button
    }) : undefined;
    const localRootRef = _react.useRef(null);
    const rootRef = (0, _reactcomponents.useMergedRefs)(ref, localRootRef);
    const state = {
        components: {
            root: 'div',
            expandButton: _reactcomponents.Button,
            searchBox: _reactcomponents.SearchBox
        },
        root: _reactcomponents.slot.always((0, _reactcomponents.getIntrinsicElementProps)('div', {
            ref: rootRef,
            ...props
        }), {
            elementType: 'div'
        }),
        expandButton,
        searchBox,
        expanded
    };
    const expandOnClick = _react.useCallback(()=>{
        onExpandedChange === null || onExpandedChange === void 0 ? void 0 : onExpandedChange({
            expanded: true
        });
        setExpanded(true);
    }, [
        onExpandedChange,
        setExpanded
    ]);
    if (state.expandButton) {
        state.expandButton.onClick = (0, _reactcomponents.mergeCallbacks)(state.expandButton.onClick, expandOnClick);
    }
    return state;
};
// This selector is used to determine if focus is moving out of the SearchBox and into the Tabs. By default the Tabs are in a Tabster arrow group so a `data-tabster-dummy` elementType
// is the first to recieve focus.
const groundingCommandBarTabListInteractiveSelector = `.${_GroundingCommandBar.groundingCommandBarClassNames.root} .${_GroundingCommandBarOverflowMenu.GroundingCommandBarOverflowMenuClassNames.menuButton},.${_GroundingCommandBarTab.groundingCommandBarTabClassNames.tab},[data-tabster-dummy]`;
const useExpandingSearchBox = (props)=>{
    var _props_searchBox;
    const { expanded, focusSearchBoxOnExpand = true, collapseOnUseTabs = false, onExpandedChange, setExpanded } = props;
    const searchBox = expanded ? _reactcomponents.slot.optional(props.searchBox, {
        renderByDefault: true,
        elementType: _reactcomponents.SearchBox
    }) : undefined;
    const searchBoxRootSlot = searchBox ? _reactcomponents.slot.always(searchBox.root, {
        elementType: 'span'
    }) : undefined;
    const searchBoxExpandOnMountRef = useExpandOnMount({
        expanded,
        focusSearchBoxOnExpand
    });
    const searchBoxRef = (0, _reactcomponents.useMergedRefs)(searchBoxExpandOnMountRef, (_props_searchBox = props.searchBox) === null || _props_searchBox === void 0 ? void 0 : _props_searchBox.ref);
    // The SearchBox ref goes to the `input` slot by default, so we need a root ref in addition.
    const searchBoxLocalRootRef = _react.useRef(null);
    const searchBoxRootRef = (0, _reactcomponents.useMergedRefs)(searchBoxLocalRootRef, searchBoxRootSlot === null || searchBoxRootSlot === void 0 ? void 0 : searchBoxRootSlot.ref);
    const onSearchBoxBlur = _react.useCallback((event)=>{
        var // If focus is moving within the search box, don't collapse
        _searchBoxLocalRootRef_current, _event_relatedTarget;
        if (((_searchBoxLocalRootRef_current = searchBoxLocalRootRef.current) === null || _searchBoxLocalRootRef_current === void 0 ? void 0 : _searchBoxLocalRootRef_current.contains(event.relatedTarget)) || // If the user is using the Tabs, don't collapse
        !collapseOnUseTabs && ((_event_relatedTarget = event.relatedTarget) === null || _event_relatedTarget === void 0 ? void 0 : _event_relatedTarget.matches(groundingCommandBarTabListInteractiveSelector))) {
            return;
        }
        onExpandedChange === null || onExpandedChange === void 0 ? void 0 : onExpandedChange({
            expanded: false
        });
        setExpanded(false);
    }, [
        collapseOnUseTabs,
        onExpandedChange,
        setExpanded
    ]);
    if (searchBox) {
        searchBox.ref = searchBoxRef;
        searchBox.onBlur = (0, _reactcomponents.mergeCallbacks)(searchBox.onBlur, onSearchBoxBlur);
        if (searchBoxRootSlot) {
            searchBoxRootSlot.ref = searchBoxRootRef;
            searchBox.root = searchBoxRootSlot;
        }
    }
    return searchBox;
};
const useExpandOnMount = (props)=>{
    const { expanded, focusSearchBoxOnExpand } = props;
    const [expandedOnMount] = _react.useState(expanded);
    // If the search box is expanded on mount, we don't want to focus it that render
    // Only if search box started collapsed and was later expanded.
    const initialFocusSuppressed = _react.useRef(!focusSearchBoxOnExpand || !expandedOnMount);
    const searchBoxCallbackRef = _react.useCallback((elem)=>{
        if (!elem) {
            return;
        }
        if (expandedOnMount && !initialFocusSuppressed.current) {
            // The search box starts expanded, so we don't want to focus it on first mount
            initialFocusSuppressed.current = true;
            return;
        }
        if (focusSearchBoxOnExpand) {
            elem === null || elem === void 0 ? void 0 : elem.focus();
        }
    }, [
        expandedOnMount,
        focusSearchBoxOnExpand
    ]);
    return searchBoxCallbackRef;
}; //# sourceMappingURL=useGroundingMenuSearchBox.js.map
