import * as React from 'react';
import { getIntrinsicElementProps, MenuList, MenuPopover, MenuTrigger, MenuButton, slot, useOverflowMenu, useIsOverflowItemVisible, useTabListContext_unstable, MenuItem } from '@fluentui/react-components';
import { useGroundingCommandBarTabValue } from '../../utils';
const OverflowMenuItem = props => {
  const {
    children,
    onClick
  } = props;
  const value = useGroundingCommandBarTabValue(props.value);
  const isVisible = useIsOverflowItemVisible(value);
  if (isVisible) {
    return null;
  }
  return /*#__PURE__*/React.createElement(MenuItem, {
    onClick: onClick
  }, children);
};
/**
 * Create the state required to render GroundingCommandBarOverflowMenu.
 *
 * The returned state can be modified with hooks such as useGroundingCommandBarOverflowMenuStyles_unstable,
 * before being passed to renderGroundingCommandBarOverflowMenu_unstable.
 *
 * @param props - props from this instance of GroundingCommandBarOverflowMenu
 * @param ref - reference to root HTMLElement of GroundingCommandBarOverflowMenu
 */
export const useGroundingCommandBarOverflowMenu_unstable = (props, ref) => {
  const {
    children,
    onTabSelect,
    overflowButtonLabel,
    ...rest
  } = props;
  const {
    ref: overflowRef,
    overflowCount,
    isOverflowing
  } = useOverflowMenu();
  const onItemClick = React.useCallback((e, tabValue) => {
    onTabSelect === null || onTabSelect === void 0 ? void 0 : onTabSelect(e, {
      value: tabValue
    });
  }, [onTabSelect]);
  const overflowItems = React.useMemo(() => React.Children.map(children, child => {
    if ( /*#__PURE__*/React.isValidElement(child)) {
      var _child_key;
      return /*#__PURE__*/React.createElement(OverflowMenuItem, {
        ...child.props,
        onClick: e => onItemClick(e, child.props.value),
        key: (_child_key = child.key) === null || _child_key === void 0 ? void 0 : _child_key.toString()
      });
    } else {
      return undefined;
    }
  }), [children, onItemClick]);
  const registeredTabData = useTabListContext_unstable(ctx => ctx.getRegisteredTabs)();
  const selectedValue = useTabListContext_unstable(ctx => ctx.selectedValue);
  const baseOverflowButtonLabel = `${overflowCount} more`;
  const [defaultOverflowButtonLabel, setDefaultOverflowButtonLabel] = React.useState(baseOverflowButtonLabel);
  // Calculate label for overflow button
  React.useEffect(() => {
    var _registeredTabData_registeredTabs_JSON_stringify_ref_current, _registeredTabData_registeredTabs_JSON_stringify_ref, _registeredTabData_registeredTabs_JSON_stringify;
    var _overflowItems_length;
    const hasVisibleTabs = overflowCount < ((_overflowItems_length = overflowItems === null || overflowItems === void 0 ? void 0 : overflowItems.length) !== null && _overflowItems_length !== void 0 ? _overflowItems_length : Number.MAX_SAFE_INTEGER);
    if (!selectedValue || hasVisibleTabs) {
      setDefaultOverflowButtonLabel(baseOverflowButtonLabel);
      return;
    }
    // If all tabs are overflowed, use the selected tab's label as the overflow button label
    const selectedLabel = (_registeredTabData_registeredTabs_JSON_stringify = registeredTabData.registeredTabs[JSON.stringify(selectedValue)]) === null || _registeredTabData_registeredTabs_JSON_stringify === void 0 ? void 0 : (_registeredTabData_registeredTabs_JSON_stringify_ref = _registeredTabData_registeredTabs_JSON_stringify.ref) === null || _registeredTabData_registeredTabs_JSON_stringify_ref === void 0 ? void 0 : (_registeredTabData_registeredTabs_JSON_stringify_ref_current = _registeredTabData_registeredTabs_JSON_stringify_ref.current) === null || _registeredTabData_registeredTabs_JSON_stringify_ref_current === void 0 ? void 0 : _registeredTabData_registeredTabs_JSON_stringify_ref_current.innerText;
    setDefaultOverflowButtonLabel(selectedLabel !== null && selectedLabel !== void 0 ? selectedLabel : baseOverflowButtonLabel);
  }, [baseOverflowButtonLabel, overflowCount, overflowItems === null || overflowItems === void 0 ? void 0 : overflowItems.length, registeredTabData.registeredTabs, selectedValue]);
  var _overflowButtonLabel;
  const buttonLabel = (_overflowButtonLabel = overflowButtonLabel === null || overflowButtonLabel === void 0 ? void 0 : overflowButtonLabel(overflowCount)) !== null && _overflowButtonLabel !== void 0 ? _overflowButtonLabel : defaultOverflowButtonLabel;
  return {
    isOverflowing,
    components: {
      root: 'span',
      menuTrigger: MenuTrigger,
      menuButton: MenuButton,
      menuPopover: MenuPopover,
      menuList: MenuList
    },
    root: slot.always(getIntrinsicElementProps('span', {
      ref,
      ...rest
    }), {
      elementType: 'span'
    }),
    menuTrigger: slot.optional(props.menuTrigger, {
      renderByDefault: true,
      elementType: MenuTrigger
    }),
    menuButton: slot.optional(props.menuButton, {
      defaultProps: {
        ref: overflowRef,
        appearance: 'subtle',
        shape: 'circular',
        children: buttonLabel,
        role: 'tab'
      },
      renderByDefault: true,
      elementType: MenuButton
    }),
    menuPopover: slot.optional(props.menuPopover, {
      renderByDefault: true,
      elementType: MenuPopover
    }),
    menuList: slot.optional(props.menuList, {
      defaultProps: {
        children: overflowItems
      },
      renderByDefault: true,
      elementType: MenuList
    })
  };
};
//# sourceMappingURL=useGroundingCommandBarOverflowMenu.js.map